def getConfirmation(title, question, fn, fnParams):
	'''
	Opens the popup in which user can give confirmation
	On confirmation the fn will be called with fnParams
	On cancel the Popup will be closed.
	
	Args:
	        title (str): confirmation popup - title.
	        question (str): confirmation popup - messsage.
	        fn (function pointer or string path to function): reference to function or function path that should be called on confirmation.
	        fnParams (tuple): execution function parameters.
	
	    Returns:
	        None
	'''
	uID = Utils.common.uniqueID()
	system.perspective.openPopup(	uID,
									'Popups/Confirmation',
									params = {	'title': title,
												'question': question,
												'fn': fn,
												'fnParams': fnParams,
												'id': uID
												},
									showCloseIcon = True,
									modal = False
									)

def executeFunction(fn, *fnArgs):
	fn(*fnArgs)
	
	
def getFunctionFromStr(fnPath):
	import importlib
	modulePathSplit = fnPath.split('.')[:-1]
	functionName = fnPath.split('.')[-1]
	moduleName = '.'.join(modulePathSplit)
	try:
		module = importlib.import_module(moduleName)
		function = getattr(module, functionName)
		return function
	except:
		return None


def confirmAction(fn, args):
	from functools import partial
	if isinstance(fn, unicode) or isinstance(fn, str):
		fn = getFunctionFromStr(fn)
	if isinstance(args, unicode) or isinstance(args, str):
		args = tuple(args)
	partialCall = partial(fn, *args)
	executeFunction(partialCall)